@@ -16,7 +16,11 @@ from aiohttp.web_response import StreamResponse, json_response
 from aiohttp.web_runner import ServerRunner
 from aiohttp.web_server import Server
 
-from aresponses.errors import NoRouteFoundError, UnusedRouteError, UnorderedRouteCallError
+from aresponses.errors import (
+    NoRouteFoundError,
+    UnusedRouteError,
+    UnorderedRouteCallError,
+)
 from aresponses.utils import _text_matches_pattern, ANY
 
 logger = logging.getLogger(__name__)
@@ -44,7 +48,15 @@ class RawResponse(StreamResponse):
 
 
 class Route:
-    def __init__(self, method_pattern=ANY, host_pattern=ANY, path_pattern=ANY, body_pattern=ANY, match_querystring=False, repeat=1):
+    def __init__(
+        self,
+        method_pattern=ANY,
+        host_pattern=ANY,
+        path_pattern=ANY,
+        body_pattern=ANY,
+        match_querystring=False,
+        repeat=1,
+    ):
         self.method_pattern = method_pattern
         self.host_pattern = host_pattern
         self.path_pattern = path_pattern
@@ -73,13 +85,17 @@ class Route:
     def __str__(self):
         return (
             f"method={self.method_pattern} host_pattern={self.host_pattern} "
-            f"path={self.path_pattern} body={self.body_pattern} match_querystring={self.match_querystring}"
+            f"path={self.path_pattern} body={self.body_pattern} "
+            f"match_querystring={self.match_querystring}"
         )
 
     def __repr__(self):
         return (
-            f"Route(method={repr(self.method_pattern)}, host_pattern={repr(self.host_pattern)}, "
-            f"path={repr(self.path_pattern)}, body={repr(self.body_pattern)}, match_querystring={repr(self.match_querystring)})"
+            f"Route(method={repr(self.method_pattern)}, "
+            f"host_pattern={repr(self.host_pattern)}, "
+            f"path={repr(self.path_pattern)}, "
+            f"body={repr(self.body_pattern)}, "
+            f"match_querystring={repr(self.match_querystring)})"
         )
 
 
@@ -112,13 +128,24 @@ class ResponsesMockServer(BaseTestServer):
     async def _handler(self, request):
         self._request_count += 1
         route, response = await self._find_response(request)
-        # ensures the request content is loaded even if the handler didn't need it. This makes it available in the
-        # `aresponses.history`
+        # ensures the request content is loaded even if the handler didn't
+        # need it. This makes it available in`aresponses.history`
         await request.text()
         self._history.append(RoutingLog(request, route, response))
         return response
 
-    def add(self, host_pattern=ANY, path_pattern=ANY, method_pattern=ANY, response="", *, route=None, body_pattern=ANY, match_querystring=False, repeat=1):
+    def add(
+        self,
+        host_pattern=ANY,
+        path_pattern=ANY,
+        method_pattern=ANY,
+        response="",
+        *,
+        route=None,
+        body_pattern=ANY,
+        match_querystring=False,
+        repeat=1,
+    ):
         """
         Adds a route and response to the mock server.
 
@@ -128,7 +155,8 @@ class ResponsesMockServer(BaseTestServer):
         :param path_pattern:
         :param method_pattern:
         :param response:
-        :param route: A Route object.  Overrides all args except for `response`. Useful for custom matching.
+        :param route: A Route object.  Overrides all args except for `response`.
+                        Useful for custom matching.
         :param body_pattern:
         :param match_querystring:
         :param repeat:
@@ -195,19 +223,27 @@ class ResponsesMockServer(BaseTestServer):
                 return self._old_resolver_mock(slf, *args, **kwargs)
 
         class DirectClientRequest(ClientRequest):
-            def is_ssl(slf) -> bool:
+            def is_ssl(slf) -> bool:  # noqa
                 return slf._aresponses_direct_is_ssl()
 
         connector = DirectTcpConnector()
 
-        original_request = request.clone(scheme="https" if request.headers["AResponsesIsSSL"] else "http")
+        original_request = request.clone(
+            scheme="https" if request.headers["AResponsesIsSSL"] else "http"
+        )
 
         headers = {k: v for k, v in request.headers.items() if k != "AResponsesIsSSL"}
 
-        async with ClientSession(connector=connector, request_class=DirectClientRequest) as session:
+        async with ClientSession(
+            connector=connector, request_class=DirectClientRequest
+        ) as session:
             request_method = getattr(session, request.method.lower())
-            async with request_method(original_request.url, headers=headers, data=(await request.read())) as r:
-                headers = {k: v for k, v in r.headers.items() if k.lower() == "content-type"}
+            async with request_method(
+                original_request.url, headers=headers, data=(await request.read())
+            ) as r:
+                headers = {
+                    k: v for k, v in r.headers.items() if k.lower() == "content-type"
+                }
                 data = await r.read()
                 response = self.Response(body=data, status=r.status, headers=headers)
                 return response
@@ -218,7 +254,16 @@ class ResponsesMockServer(BaseTestServer):
         self._old_resolver_mock = TCPConnector._resolve_host
 
         async def _resolver_mock(_self, host, port, traces=None):
-            return [{"hostname": host, "host": "127.0.0.1", "port": self.port, "family": _self._family, "proto": 0, "flags": 0}]
+            return [
+                {
+                    "hostname": host,
+                    "host": "127.0.0.1",
+                    "port": self.port,
+                    "family": _self._family,
+                    "proto": 0,
+                    "flags": 0,
+                }
+            ]
 
         TCPConnector._resolve_host = _resolver_mock
 
@@ -246,6 +291,7 @@ class ResponsesMockServer(BaseTestServer):
     async def __aexit__(self, exc_type, exc_val, exc_tb):
         TCPConnector._resolve_host = self._old_resolver_mock
         ClientRequest.is_ssl = self._old_is_ssl
+        ClientRequest.__init__ = self._old_init
 
         await self.close()
 
@@ -256,12 +302,17 @@ class ResponsesMockServer(BaseTestServer):
 
     def assert_called_in_order(self):
         if self._first_unordered_route is not None:
-            raise UnorderedRouteCallError(f"Route used out of order: {self._first_unordered_route}")
+            raise UnorderedRouteCallError(
+                f"Route used out of order: {self._first_unordered_route}"
+            )
 
     def assert_all_requests_matched(self):
         if self._unmatched_requests:
             request = self._unmatched_requests[0]
-            raise NoRouteFoundError(f"No match found for request: {request.method} {request.host} {request.path}")
+            raise NoRouteFoundError(
+                f"No match found for request: "
+                f"{request.method} {request.host} {request.path}"
+            )
 
     def assert_plan_strictly_followed(self):
         self.assert_no_unused_routes()
@@ -273,7 +324,7 @@ class ResponsesMockServer(BaseTestServer):
         return self._history
 
 
-@pytest.fixture
+@pytest.fixture()
 async def aresponses(event_loop) -> ResponsesMockServer:
     async with ResponsesMockServer(loop=event_loop) as server:
         yield server
